@@ -234,7 +234,7 @@ from ae.i18n import default_language, get_f_string, translation
 from ae.gui_app import FLOW_KEY_SEP, module_globals, id_of_flow, MainAppBase                # type: ignore
 
 
-__version__ = '0.1.12'
+__version__ = '0.1.13'
 
 
 HELP_ID_PREFIX_FLOW = 'help_flow#'                                  #: message id prefix for flow change help texts
@@ -364,38 +364,40 @@ class HelpAppBase(MainAppBase, ABC):
         :param widget:          the popup/dropdown/container widget to be moved to the top.
         """
 
+    # overwritten methods
+
+    def change_app_state(self, state_name: str, state_value: Any, send_event: bool = True):
+        """ change app state via :meth:`~ae.gui_app.MainAppBase.change_app_state`, show help text in active help mode.
+
+        All parameters are documented in the overwritten method :meth:`~ae.gui_app.MainAppBase.change_app_state`.
+        """
+        help_vars = dict(state_name=state_name, state_value=state_value, send_event=send_event)
+        if not self.help_app_state_display(help_vars):
+            super().change_app_state(state_name, state_value, send_event=send_event)
+            self.help_app_state_display(help_vars, changed=True)
+
+    # noinspection PyIncorrectDocstring
     def change_flow(self, new_flow_id: str, popups_to_close: Sequence = (), **event_kwargs) -> bool:
         """ change/switch flow id - overriding :meth:`~ae.gui_app.MainAppBase.change_flow`.
 
-        :param new_flow_id:     new flow id (maybe overwritten by event handlers in event_kwargs['flow_id']).
-        :param popups_to_close: optional sequence of widgets to be closed on confirmed flow change.
+        More detailed documentation of the parameters you find in the overwritten method
+        :meth:`~ae.gui_app.MainAppBase.change_app_state`.
+
         :param event_kwargs:    optional args to pass additional data or info onto and from the event handler
                                 and to the help text renderer.
 
-                                info pass onto event handler (e.g. from :attr:`~ae.kivy_app.FlowButton.tap_kwargs`
-                                or :attr:`~ae.kivy_app.FlowToggler.tap_kwargs`):
-                                    * `popup_kwargs`: optional dict passed to the Popup `__init__` method,
-                                      like e.g. dict(parent=parent_widget_of_popup, data=...).
-                                    * `tap_widget`: optional tapped button widget instance (initiating this
-                                      flow change).
-
-                                info passed from the event handler:
-                                    * `flow_id`: process :attr:`~ae.gui_app.MainAppBase.flow_path` as specified by the
-                                      :paramref:`~change_flow.new_flow_id` argument, but then overwrite this flow id
-                                      with this event arg value for to set :attr:`~ae.gui_app.MainAppBase.flow_id`.
-
                                 passed to the help text renderer:
-                                    * `count`: optional number used for to render a pluralized help text
-                                      for this flow change.
+
+                                * `count`: optional number used for to render a pluralized help text
+                                  for this flow change.
 
         :return:                True if flow changed and got confirmed by a declared custom event handler
                                 (either event method or Popup class) of the app
                                 AND if the help mode is *not* active or the calling widget is selected
                                 in active help mode, else False.
                                 Some flow actions are handled internally independent from the
-                                return value of a found/declared
-                                custom event handler, like e.g. `'enter'` or `'leave'` will always
-                                extend/reduce the flow path and the action `'focus'` will give the
+                                return value of a found/declared custom event handler, like e.g. `'enter'` or `'leave'`
+                                will always extend/reduce the flow path and the action `'focus'` will give the
                                 indexed widget the input focus (these exceptions are configurable via
                                 the list :data:`ACTIONS_CHANGING_FLOW_WITHOUT_CONFIRMATION`).
         """
@@ -410,17 +412,7 @@ class HelpAppBase(MainAppBase, ABC):
                 return True
         return False
 
-    def change_app_state(self, state_name: str, state_value: Any, send_event: bool = True):
-        """ change app state via :meth:`~ae.gui_app.MainAppBase.change_app_state`, show help text in active help mode.
-
-        :param state_name:      name of the app state to change.
-        :param state_value:     new value of the app state to change.
-        :param send_event:      pass False to prevent to send/call the on_<state_name> event to the main app instance.
-        """
-        help_vars = dict(state_name=state_name, state_value=state_value, send_event=send_event)
-        if not self.help_app_state_display(help_vars):
-            super().change_app_state(state_name, state_value, send_event=send_event)
-            self.help_app_state_display(help_vars, changed=True)
+    # help specific methods
 
     def help_app_state_display(self, help_vars: Dict[str, Any], changed: bool = False) -> bool:
         """ actualize the help layout if active, before and after the change of the app state.
